Changelog
=========

0.0.2 (2015-01-20)
------------------

New
~~~

- [basename] added a full basename support (with suffix removal).
  [Valentin Lab]

- [chown] walk in alphabetical order and support setting only user or
  group, and support of numerical ids. [Valentin Lab]

- Big changes to the API, ``rmtree`` now in ``rm``, ``zip_file`` return
  filename. [Valentin Lab]

0.0.1 (2013-02-12)
------------------

- First import. [Valentin Lab]


